Learn R Programming

ravepipeline (version 0.0.1)

pipeline-knitr-markdown: Configure 'rmarkdown' files to build 'RAVE' pipelines

Description

Allows building 'RAVE' pipelines from 'rmarkdown' files. Please use it in 'rmarkdown' scripts only. Use pipeline_create_template to create an example.

Usage

configure_knitr(languages = c("R", "python"))

pipeline_setup_rmd( module_id, env = parent.frame(), collapse = TRUE, comment = "#>", languages = c("R", "python"), project_path = getOption("raveio.pipeline.project_root", default = rs_active_project(child_ok = TRUE, shiny_ok = TRUE)) )

pipeline_render( module_id, ..., env = new.env(parent = parent.frame()), entry_file = "main.Rmd", project_path = getOption("raveio.pipeline.project_root", default = rs_active_project(child_ok = TRUE, shiny_ok = TRUE)) )

Value

A function that is supposed to be called later that builds the pipeline scripts

Arguments

languages

one or more programming languages to support; options are 'R' and 'python'

module_id

the module ID, usually the name of direct parent folder containing the pipeline file

env

environment to set up the pipeline translator

collapse, comment

passed to set method of opts_chunk

project_path

the project path containing all the pipeline folders, usually the active project folder

...

passed to internal function calls

entry_file

the file to compile; default is "main.Rmd"

Examples

Run this code

configure_knitr("R")

if (FALSE) {

# Requires to configure Python
configure_knitr("python")

# This function must be called in an Rmd file setup block
# for example, see
# https://rave.wiki/posts/customize_modules/python_module_01.html

pipeline_setup_rmd("my_module_id")

}

Run the code above in your browser using DataLab