powered by
The official built-in pipeline repository is located at https://github.com/rave-ieeg/rave-pipelines; The code snippet repository is located at https://github.com/rave-ieeg/rave-gists.
ravepipeline_finalize_installation( upgrade = c("ask", "always", "never", "config-only", "data-only"), async = FALSE, ... )
A list built-in pipelines will be installed, the function itself returns nothing.
rules to upgrade dependencies; default is to ask if needed
whether to run in the background; ignore for now
ignored; reserved for external calls.
if (FALSE) { # This function requires connection to the Github, and must run # under interactive session since an user prompt will be displayed ravepipeline_finalize_installation() }
Run the code above in your browser using DataLab